@@ -93,6 +93,11 @@ DialogSettings::DialogSettings(QWidget * parent) : QDialog(parent), ui(new Ui::D
   ui->sbPreviewTimeout->setValue(Settings::previewTimeout());
   ui->cbPreviewZoom->setChecked(Settings::previewZoomAlwaysEnabled());
   ui->cbNotifyFailedUpdate->setChecked(Settings::notifyFailedStartupUpdate());
+#ifdef _GMIC_USE_HOSTED_SETTINGS_
+  ui->cbHighDPI->setEnabled(false);
+#else
+  ui->cbHighDPI->setChecked(Settings::highDPIEnabled());
+#endif
 
   connect(ui->pbOk, &QPushButton::clicked, this, &DialogSettings::onOk);
   connect(ui->rbLeftPreview, &QRadioButton::toggled, this, &DialogSettings::onRadioLeftPreviewToggled);
@@ -119,6 +124,7 @@ DialogSettings::DialogSettings(QWidget * parent) : QDialog(parent), ui(new Ui::D
 #else
   connect(ui->cbNotifyFailedUpdate, &QCheckBox::toggled, this, &DialogSettings::onNotifyStartupUpdateFailedToggle);
 #endif
+  connect(ui->cbHighDPI, &QCheckBox::toggled, this, &DialogSettings::onHighDPIToggled);
 
 #ifdef _GMIC_QT_DISABLE_TRANSLATION_
   {
@@ -144,6 +150,7 @@ DialogSettings::DialogSettings(QWidget * parent) : QDialog(parent), ui(new Ui::D
     ui->rbRightPreview->setPalette(p);
     ui->cbShowLogos->setPalette(p);
     ui->cbNotifyFailedUpdate->setPalette(p);
+    ui->cbHighDPI->setPalette(p);
   }
 #endif
   ui->pbOk->setFocus();
@@ -194,6 +201,11 @@ void DialogSettings::onNotifyStartupUpdateFailedToggle(bool on)
   Settings::setNotifyFailedStartupUpdate(on);
 }
 
+void DialogSettings::onHighDPIToggled(bool on)
+{
+  Settings::setHighDPIEnabled(on);
+}
+
 void DialogSettings::enableUpdateButton()
 {
   ui->pbUpdate->setEnabled(true);
